@@ -14,8 +14,6 @@ ENV_VAR = 'ONHOLD'
 KB = 2 ** 10
 CHUNK = 64 * KB
 
-BELL_CMD = "tput bel"
-
 
 def is_pipeline() -> bool:
   return not stdin.isatty()
@@ -44,7 +42,7 @@ def using_path(
   warn: bool,
   default: Optional[Path] = DEFAULT_SONG,
   env_var: str = ENV_VAR,
-) -> ContextManager[Path]:
+) -> ContextManager[Optional[Path]]:
   path = default
 
   if sound_path:
